@@ -8,24 +8,17 @@ class Servico:
 
     def __init__(self, nome_servico):
         self.nome_servico = nome_servico
-        self.id = self.get_id()
-        self.service_params = {
-            'servico': self.nome_servico,
-            'hora_agendamento': '01:00',
-            'forcar_execucao': True,
-            'ativo': True,
-            'tipo': 'entrada',
-        }
+        self.id = None
 
     def get_or_create(self, service_params={}):
         response = mindset_request('GET', '/servicos', query_params={'servico': self.nome_servico})
         if not response.ok:
             return response, {}
         if not response.json():
-            self.service_params.update(service_params)
-            response = mindset_request('POST', '/servicos', json=self.service_params)
-            self.id = self.get_id()
+            response = mindset_request('POST', '/servicos', json=service_params)
+            self.id = response.json()['_id']
             return (response, response.json()) if response.ok else (response, {})
+        self.id = response.json()[0]['_id']
         return (response, response.json()[0])
 
     def ativo(self):
@@ -82,8 +75,12 @@ class Servico:
         return mindset_request('GET', f'/servicos/{self.id}/status')
 
     def em_execucao(self):
-        json = self.status().json()
-        return False if not json else "E" == json[0].get('status', False)
+        response = self.status()
+        if response.ok and response.json():
+            return "E" == response.json()[0].get('status', False)
+        if response.ok and not response.json():
+            return False
+        return True
 
     def executado(self):
         response = Controle.get({'servico': self.id})
@@ -101,9 +98,8 @@ class Servico:
         if self.forcar_execucao():
             return True
         hoje, json = datetime.now(), response.json()[0]
-        fim_execucao = {
-            19: f'{json.get("fim_execucao")}.0'
-        }.get(len(json.get('fim_execucao')), json.get('fim_execucao'))
+        json['fe'] = json.pop('fim_execucao')
+        fim_execucao = {19: f'{json.get("fe")}.0'}.get(len(json.get('fe')), json.get('fe'))
         no_horario = hoje.time() >= datetime.strptime(
             json.get('hora_agendamento', '01:00:00'), '%H:%M:%S',
         ).time()
@@ -121,6 +117,9 @@ class Servico:
             ]
         )
 
+        def limpar_controle(self):
+            return Controle.limpar({'_id_servico': self.id})
+
 
 class Controle:
 
